@@ -1,18 +1,17 @@
-## Copyright (C) 2008  Francesco Potort  <pot@gnu.org>
+## Copyright (C) 2008 Francesco Potort <pot@gnu.org>
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3, or (at your option)
-## any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this software; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{y} =} pdist (@var{x})
@@ -53,7 +52,7 @@
 ## coordinate.
 ##
 ## @item "mahalanobis"
-## Mahalanobis distance: @seealso{mahalanobis}.
+## Mahalanobis distance: see the function mahalanobis.
 ##
 ## @item "cityblock"
 ## City Block metric, aka Manhattan distance.
@@ -85,7 +84,7 @@
 ## @item "chebychev"
 ## Chebychev distance: the maximum coordinate difference.
 ## @end table 
-## @seealso{linkage,squareform}
+## @seealso{linkage, mahalanobis, squareform}
 ## @end deftypefn
 
 ## Author: Francesco Potort  <pot@gnu.org>
